@@ -56,7 +56,9 @@ typedef enum {
 	LM_DISCONNECT_REASON_PING_TIME_OUT,
 	LM_DISCONNECT_REASON_HUP,
 	LM_DISCONNECT_REASON_ERROR,
-	LM_DISCONNECT_REASON_UNKNOWN
+	LM_DISCONNECT_REASON_UNKNOWN,
+	LM_DISCONNECT_REASON_RESOURCE_CONFLICT,
+	LM_DISCONNECT_REASON_INVALID_XML
 } LmDisconnectReason;
 
 typedef enum {
